@@ -280,7 +280,10 @@ class OpenEVSE:
             self._status.update(data)
 
             if self.callback is not None:
-                self.callback()  # pylint: disable=not-callable
+                if self.is_coroutine_function(self.callback):
+                    await self.callback()  # pylint: disable=not-callable
+                else:
+                    self.callback()  # pylint: disable=not-callable
 
     async def ws_disconnect(self) -> None:
         """Disconnect the websocket listener."""
@@ -288,6 +291,10 @@ class OpenEVSE:
         await self.websocket.close()
         self._ws_listening = False
 
+    def is_coroutine_function(self, callback):
+        """Check if a callback is a coroutine function."""
+        return asyncio.iscoroutinefunction(callback)
+
     @property
     def ws_state(self) -> Any:
         """Return the status of the websocket listener."""
